# ExoGibbs

Differentiable Thermochemical Equilibrium, powered by JAX. 

The optimization scheme is based on the Lagrange multiplier, similar to NASA/CEA algorithm. 
The terminology follows Smith and Missen. 

ExoGibbs is designed to plug into [ExoJAX](https://github.com/HajimeKawahara/exojax) and enable gradient-based equilibrium retrievals. 
It is still in a very beta stage, so please use it at your own risk.